@@ -14,7 +14,7 @@ gPreBuildVariants = [
     {
         'name': 'main-ppc64',
         'target': '10.5',
-        'cflags': '-g -isysroot /Developer/SDKs/MacOSX10.5.sdk -arch x86_64',
+        'cflags': '-g -isysroot /Developer/SDKs/MacOSX10.5.sdk -arch ppc64',
         'cc': 'gcc-4.2',
     },
     {
@@ -103,6 +103,8 @@ def main(all=False, arch=None):
                     root = fp.read().strip()
                     fp.close()
 
+                print ("rebuilding %s"%(entry['name']))
+
                 CC=os.path.join(root, 'usr', 'bin', entry['cc'])
                 CFLAGS = BASE_CFLAGS + ' ' + entry['cflags'].replace('@@XCODE_ROOT@@', root)
                 os.environ['MACOSX_DEPLOYMENT_TARGET'] = entry['target']
