@@ -86,6 +86,18 @@ class PythonStandalone(macholib.MachOStandalone.MachOStandalone):
         dest = os.path.join(self.dest, os.path.basename(src))
         if os.path.islink(src):
             dest = os.path.join(self.dest, os.path.basename(os.path.realpath(src)))
+
+            # Ensure that the orginal name also exists, avoids problems when
+            # the filename is used from Python (see issue #65)
+            # 
+            # NOTE: The if statement checks that the target link won't 
+            #       point to itself, needed for systems like homebrew that
+            #       store symlinks in "public" locations that point to
+            #       files of the same name in a per-package install location.
+            link_dest = os.path.join(self.dest, os.path.basename(src))
+            if os.path.basename(link_dest) != os.path.basename(dest):
+                os.symlink(os.path.basename(dest), link_dest)
+
         else:
             dest = os.path.join(self.dest, os.path.basename(src))
         return self.appbuilder.copy_dylib(src, dest)
@@ -487,6 +499,27 @@ class py2app(Command):
             yield runtime
 
     def run(self):
+        if sysconfig.get_config_var('PYTHONFRAMEWORK') is None:
+            if not sysconfig.get_config_var('Py_ENABLE_SHARED'):
+                raise DistutilsPlatformError("This python does not have a shared library or framework")
+
+            else:
+                # Issue .. in py2app's tracker, and issue .. in python's tracker: a unix-style shared 
+                # library build did not read the application environment correctly. The collection of
+                # if statements below gives a clean error message when py2app is started, instead of
+                # building a bundle that will give a confusing error message when started.
+                msg = "py2app is not supported for a shared library build with this version of python"
+                if sys.version_info[:2] < (2,7):
+                    raise DistutilsPlatformError(msg)
+                elif sys.version_info[:2] == (2,7) and sys.version[3] < 4:
+                    raise DistutilsPlatformError(msg)
+                elif sys.version_info[0] == 3 and sys.version_info[1] < 2:
+                    raise DistutilsPlatformError(msg)
+                elif sys.version_info[0] == 3 and sys.version_info[1] == 2 and sys.version_info[3] < 3:
+                    raise DistutilsPlatformError(msg)
+                elif sys.version_info[0] == 3 and sys.version_info[1] == 3 and sys.version_info[3] < 1:
+                    raise DistutilsPlatformError(msg)
+
         if hasattr(self.distribution, "install_requires") \
                 and self.distribution.install_requires:
 
@@ -969,7 +1002,7 @@ class py2app(Command):
         for dname in package.packagepath:
             filenames = list(filter(datafilter, zipio.listdir(dname)))
             for fname in filenames:
-                if fname in ('.svn', 'CVS'):
+                if fname in ('.svn', 'CVS', '.hg', '.git'):
                     # Scrub revision manager junk
                     continue
                 if fname in ('__pycache__',):
