@@ -14,7 +14,7 @@ gPreBuildVariants = [
     {
         'name': 'main-ppc64',
         'target': '10.5',
-        'cflags': '-isysroot @@XCODE_ROOT@@/SDKs/MacOSX10.5.sdk -arch x86_64',
+        'cflags': '-isysroot @@XCODE_ROOT@@/SDKs/MacOSX10.5.sdk -arch ppc64',
         'cc': 'gcc-4.2',
     },
     {
@@ -38,8 +38,9 @@ gPreBuildVariants = [
     {
         'name': 'main-i386',
         'target': '10.3',
-        'cflags': '-isysroot @@XCODE_ROOT@@/SDKs/MacOSX10.4u.sdk -arch i386',
-        'cc': 'gcc-4.0',
+        #'cflags': '-isysroot @@XCODE_ROOT@@/SDKs/MacOSX10.4u.sdk -arch i386',
+        'cflags': '-arch i386',
+        'cc': 'gcc-4.2',
     },
     {
         'name': 'main-ppc',
@@ -103,7 +104,10 @@ def main(all=False, arch=None):
                     root = fp.read().strip()
                     fp.close()
 
-                CC=os.path.join(root, 'usr', 'bin', entry['cc'])
+                print ("rebuilding %s"%(entry['name']))
+
+                #CC=os.path.join(root, 'usr', 'bin', entry['cc'])
+                CC=entry['cc']
                 CFLAGS = BASE_CFLAGS + ' ' + entry['cflags'].replace('@@XCODE_ROOT@@', root)
                 os.environ['MACOSX_DEPLOYMENT_TARGET'] = entry['target']
                 os.system('"%(CC)s" -o "%(dest)s" "%(src)s" %(CFLAGS)s' % locals())
