@@ -283,14 +283,11 @@ def __load():
     import imp, os, sys
     ext = %r
     for path in sys.path:
-        print path
         if not path.endswith('lib-dynload'):
             continue
         ext_path = os.path.join(path, ext)
         if os.path.exists(ext_path):
-            #print("py2app extension module", __name__, "->", ext_path)
             mod = imp.load_dynamic(__name__, ext_path)
-            #mod.frozen = 1
             break
     else:
         raise ImportError(repr(ext) + " not found")
@@ -405,7 +402,7 @@ byte_compile(files, optimize=%r, force=%r,
                     print("skipping byte-compilation of %s to %s" % 
                           (mod.filename, dfile))
 
-SCMDIRS = ['CVS', '.svn']
+SCMDIRS = ['CVS', '.svn', '.hg', '.git']
 def skipscm(ofn):
     ofn = fsencoding(ofn)
     fn = os.path.basename(ofn)
